@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2015	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -167,6 +167,7 @@ POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor, in
 					info = connection_pool->info;
 					memset(connection_pool, 0, sizeof(POOL_CONNECTION_POOL));
 					connection_pool->info = info;
+					info->swallow_termination = 0;
 					memset(connection_pool->info, 0, sizeof(ConnectionInfo) * MAX_NUM_BACKENDS);
 					POOL_SETMASK(&oldmask);
 					return NULL;
@@ -328,12 +329,7 @@ void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend)
 		(errmsg("setting backend connection close timer"),
 			 errdetail("close time %ld", time(NULL))));
 
-	/* Set connection close time */
-	for (i = 0; i < NUM_BACKENDS; i++)
-	{
-		if (CONNECTION_SLOT(backend, i))
-			CONNECTION_SLOT(backend, i)->closetime = time(NULL);
-	}
+	MASTER_CONNECTION(backend)->closetime = time(NULL);		/* set connection close time */
 
 	if (pool_config->connection_life_time == 0)
 		return;
@@ -383,7 +379,7 @@ void pool_backend_timer(void)
 	now = time(NULL);
 
 	ereport(DEBUG1,
-			(errmsg("backend timer handler called at %ld", now)));
+		(errmsg("backend timer handler called at%ld", now)));
 
 	for (i=0;i<pool_config->max_pool;i++, p++)
 	{
@@ -822,7 +818,6 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 	POOL_CONNECTION_POOL_SLOT *s;
 	int active_backend_count = 0;
 	int i;
-	bool		status_changed = false;
 
     MemoryContext oldContext = MemoryContextSwitchTo(TopMemoryContext);
     
@@ -841,25 +836,6 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 			continue;
 		}
 
-		/*
-		 * Make sure that the global backend status in the shared memory
-		 * agrees the local status checked by VALID_BACKEND. It is possible
-		 * that the local status is up, while the global status has been
-		 * changed to down by failover.
-		 */
-		if (BACKEND_INFO(i).backend_status != CON_UP &&
-			BACKEND_INFO(i).backend_status != CON_CONNECT_WAIT)
-		{
-			ereport(DEBUG1,
-					(errmsg("creating new connection to backend"),
-					errdetail("skipping backend slot %d because global backend_status = %d",
-						   i, BACKEND_INFO(i).backend_status)));
-
-			/* sync local status with global status */
-			*(my_backend_status[i]) = BACKEND_INFO(i).backend_status;
-			continue;
-		}
-
 		s = palloc(sizeof(POOL_CONNECTION_POOL_SLOT));
 
 		if (create_cp(s, i) == NULL)
@@ -869,7 +845,7 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 			 */
 			if (pool_config->fail_over_on_backend_error)
 			{
-				notice_backend_error(i);
+				notice_backend_error(i, true);
 				ereport(FATAL,
 					(errmsg("failed to create a backend connection"),
 						 errdetail("executing failover on backend")));
@@ -889,17 +865,6 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 					/* set down status to local status area */
 					*(my_backend_status[i]) = CON_DOWN;
 
-					/* if master_node_id is not updated, then update it */
-					if (Req_info->master_node_id == i)
-					{
-						int old_master = Req_info->master_node_id;
-						Req_info->master_node_id = get_next_master_node();
-
-						ereport(LOG,
-								(errmsg("master node %d is down. Update master node to %d",
-										old_master, Req_info->master_node_id)));
-					}
-
 					/* make sure that we need to restart the process after
 					 * finishing this session
 					 */
@@ -921,16 +886,11 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 
 		pool_init_params(&s->con->params);
 	
-		if (BACKEND_INFO(i).backend_status != CON_UP)
-		{
-			BACKEND_INFO(i).backend_status = CON_UP;
-			status_changed = true;
-		}
+		BACKEND_INFO(i).backend_status = CON_UP;
 		active_backend_count++;
 	}
 
-	if (status_changed)
-		(void)write_status_file();
+	(void)write_status_file();
 
     MemoryContextSwitchTo(oldContext);
 
