@@ -905,6 +905,7 @@ POOL_STATUS Execute(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 				pool_set_writing_transaction();
 			}
 		}
+		pool_unset_query_in_progress();
 	}
 
 	return POOL_CONTINUE;
@@ -1326,7 +1327,8 @@ POOL_STATUS Bind(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 	 * other than primary node. In this case, we send a parse message to the
 	 * primary node.
 	 */
-	if (pool_config->load_balance_mode && pool_is_writing_transaction())
+	if (pool_config->load_balance_mode && pool_is_writing_transaction() &&
+		TSTATE(backend, MASTER_SLAVE ? PRIMARY_NODE_ID : REAL_MASTER_NODE_ID) == 'T')
 	{
 		if (!STREAM)
 		{
@@ -1552,9 +1554,18 @@ POOL_STATUS Close(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 	else
 	{
 		POOL_PENDING_MESSAGE *pmsg;
+		bool where_to_send_save[MAX_NUM_BACKENDS];
 
+		/* Parse_before_bind() may have sent a bind message to the primary
+		 * node id. So send the close message to the primary node as well.
+		 * Even if not, sending a close message for non existing
+		 * statement/portal is harmless. No error will happen.
+		 */
 		if (session_context->load_balance_node_id != PRIMARY_NODE_ID)
 		{
+			/* save where_to_send map */
+			memcpy(where_to_send_save, query_context->where_to_send, sizeof(where_to_send_save));
+
 			query_context->where_to_send[PRIMARY_NODE_ID] = true;
 			query_context->where_to_send[session_context->load_balance_node_id] = true;
 		}
@@ -1569,6 +1580,12 @@ POOL_STATUS Close(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 		pool_pending_message_add(pmsg);
 		pool_pending_message_free_pending_message(pmsg);
 
+		if (session_context->load_balance_node_id != PRIMARY_NODE_ID)
+		{
+			/* Restore where_to_send map */
+			memcpy(query_context->where_to_send, where_to_send_save, sizeof(where_to_send_save));		
+		}
+
 #ifdef NOT_USED
 		dump_pending_message();
 #endif
@@ -2477,7 +2494,17 @@ POOL_STATUS ProcessFrontendResponse(POOL_CONNECTION *frontend,
 		case 'H':	/* Flush */
 			if (MAJOR(backend) == PROTO_MAJOR_V3)
 			{
+				if (fkind == 'H')
+				{
+					pool_set_doing_extended_query_message();
+				}
 				status = SimpleForwardToBackend(fkind, frontend, backend, len, contents);
+
+				if (pool_is_doing_extended_query_message())
+				{
+					pool_unset_doing_extended_query_message();
+				}
+
 				break;
 			}
 
@@ -2688,13 +2715,13 @@ POOL_STATUS ProcessBackendResponse(POOL_CONNECTION *frontend,
 
 			case 'T':	/* RowDescription */
 				status = SimpleForwardToFrontend(kind, frontend, backend);
-				if ((REPLICATION || RAW_MODE) && pool_is_doing_extended_query_message())
+				if (pool_is_doing_extended_query_message())
 					pool_unset_query_in_progress();
 				break;
 
 			case 'n':	/* NoData */
 				status = SimpleForwardToFrontend(kind, frontend, backend);
-				if ((REPLICATION || RAW_MODE) && pool_is_doing_extended_query_message())
+				if (pool_is_doing_extended_query_message())
 					pool_unset_query_in_progress();
 				break;
 
