@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2017	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -62,6 +62,7 @@
 #include "auth/md5.h"
 #include "utils/pool_stream.h"
 
+char remote_ps_data[NI_MAXHOST];		/* used for set_ps_display */
 static POOL_CONNECTION_POOL_SLOT	*slots[MAX_NUM_BACKENDS];
 static volatile sig_atomic_t reload_config_request = 0;
 static volatile sig_atomic_t restart_request = 0;
@@ -160,6 +161,7 @@ void do_worker_child(void)
 		/*
 		 * If streaming replication mode, do time lag checking
 		 */
+
 		if (pool_config->sr_check_period > 0 && STREAM)
 		{
 			establish_persistent_connection();
@@ -201,7 +203,7 @@ static void establish_persistent_connection(void)
 		if (slots[i] == NULL)
 		{
                 bkinfo = pool_get_node_info(i);
-                slots[i] = make_persistent_db_connection_noerror(i, bkinfo->backend_hostname,
+                slots[i] = make_persistent_db_connection_noerror(bkinfo->backend_hostname,
 											  bkinfo->backend_port,
 											  pool_config->sr_check_database,
 											  pool_config->sr_check_user,
@@ -280,8 +282,6 @@ static void check_replication_time_lag(void)
 
 	for (i=0;i<NUM_BACKENDS;i++)
 	{
-		lsn[i] = 0;
-
 		if (!VALID_BACKEND(i))
 			continue;
 
@@ -328,6 +328,10 @@ static void check_replication_time_lag(void)
 			lsn[i] = text_to_lsn(res->data[0]);
 			free_select_result(res);
 		}
+		else
+		{
+			lsn[i] = 0;
+		}
 	}
 
 	for (i=0;i<NUM_BACKENDS;i++)
@@ -348,9 +352,9 @@ static void check_replication_time_lag(void)
 			bkinfo->standby_delay = lag;
 
 			/* Log delay if necessary */
-			if ((!strcmp(pool_config->log_standby_delay, "always") && lag > 0) ||
+			if ((pool_config->log_standby_delay == LSD_ALWAYS && lag > 0) ||
 				(pool_config->delay_threshold &&
-				 !strcmp(pool_config->log_standby_delay, "if_over_threshold") &&
+				 pool_config->log_standby_delay == LSD_OVER_THRESHOLD &&
 				 lag > pool_config->delay_threshold))
 			{
                 ereport(LOG,
@@ -440,7 +444,7 @@ static void reload_config(void)
 	ereport(LOG,
 			(errmsg("reloading config file")));
     MemoryContext oldContext = MemoryContextSwitchTo(TopMemoryContext);
-	pool_get_config(get_config_file_name(), RELOAD_CONFIG);
+	pool_get_config(get_config_file_name(), CFGCXT_RELOAD);
     MemoryContextSwitchTo(oldContext);
 	if (pool_config->enable_pool_hba)
 		load_hba(get_hba_file_name());
